@@ -20,6 +20,7 @@ class ContainerScaScan:
         tool_deseralizator: DeseralizatorGateway,
         build_id,
         token,
+        image_to_scan,
     ):
         self.tool_run = tool_run
         self.remote_config = remote_config
@@ -27,15 +28,16 @@ class ContainerScaScan:
         self.tool_deseralizator = tool_deseralizator
         self.build_id = build_id
         self.token = token
+        self.image_to_scan = image_to_scan
 
-    def get_latest_image(self):
+    def get_image(self, image_to_scan):
         """
         Process the list of images.
 
         Returns:
             list: List of processed images.
         """
-        return self.tool_images.list_images()
+        return self.tool_images.list_images(image_to_scan)
 
     def get_images_already_scanned(self):
         """
@@ -62,11 +64,11 @@ class ContainerScaScan:
         Returns:
             string: file scanning results name.
         """
-        latest_image = self.get_latest_image()
-        image_name = latest_image.tags[0]
+        matching_image = self.get_image(self.image_to_scan)
         image_scanned = None
-        if str(self.build_id) in image_name:
-            result_file = image_name + "_scan_result.json"
+        if matching_image:
+            image_name = matching_image.tags[0]
+            result_file = image_name.replace("/","_") + "_scan_result.json"
             if result_file in self.get_images_already_scanned():
                 print(f"The image {image_name} has already been scanned previously.")
                 return image_scanned
@@ -75,9 +77,7 @@ class ContainerScaScan:
             )
             self.set_image_scanned(result_file)
         else:
-            print(
-                f"'{image_name}' name does not contain build number '{self.build_id}'. Tool skipped."
-            )
+            print(f"'Not image found for {self.image_to_scan}'. Tool skipped.")
         return image_scanned
 
     def deseralizator(self, image_scanned):
